//
//  CalculatorViewController.m
//  Calculator
//
//  Created by Nathaniel Hillard on 8/20/11.
//  Copyright 2011 Loqate, Inc. All rights reserved.
//

#import "CalculatorViewController.h"

@interface CalculatorViewController()
@property (readonly) CalculatorBrain *brain;
@end

@implementation CalculatorViewController


-(CalculatorBrain *)brain
{
    if(!brain)
    {
        brain = [[CalculatorBrain alloc] init]; 
    }
    return brain;
}

- (IBAction)switchValueChanged:(UISwitch *)sender {
    if (sender.on) {
        self.brain.isDegrees = YES;
    } else {
        self.brain.isDegrees = NO;
     }
}


- (IBAction)digitPressed:(UIButton *)sender
{
    error.text = nil;
    NSString * displayContents = sender.titleLabel.text;
    
    NSString * digit;
    if([displayContents isEqual:@"π"]){
        digit = [NSString stringWithFormat:@"%g", M_PI];
        userIsInTheMiddleOfTypingANumber = NO;
    } else {
        digit = sender.titleLabel.text;
    }
    
    if(userIsInTheMiddleOfTypingANumber){
        display.text = [display.text stringByAppendingString:digit];
    } else {
        display.text = digit;
        userIsInTheMiddleOfTypingANumber = YES;
    }
}


- (IBAction)operationPressed:(UIButton *)sender
{
   // NSLog(@"The answer to %@, the universe and everything is %d.", @"life", 42);
    
    if(userIsInTheMiddleOfTypingANumber){
        self.brain.operand = [display.text doubleValue];
        userIsInTheMiddleOfTypingANumber = NO;
    }
    
    NSString *operation = sender.titleLabel.text;
   [self.brain performOperation:operation];
    

    
    if(isnan(self.brain.operand)){
        UIAlertView *alertView = [[UIAlertView alloc] initWithTitle:@"ERROR"
                                                            message:@"Sqrt of negative number!"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
        [alertView show];
        [alertView release];
        error.text = @"ERR";
    } else if (isinf(self.brain.operand)){
        UIAlertView *alertView = [[UIAlertView alloc] initWithTitle:@"ERROR"
                                                            message:@"Divide by zero error."
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
        [alertView show];
        [alertView release];
        
        error.text = @"ERR";
    } else {
       display.text = [NSString stringWithFormat:@"%g", self.brain.operand];
        error.text = nil;
        memory.text = [NSString stringWithFormat:@"%g", self.brain.storedValue];
        
        if(self.brain.isPending){
            progress.text = [display.text stringByAppendingString:operation];
        } else {
            progress.text = display.text;
        }
    }
    
}

 
- (IBAction)decimalPressed:(UIButton *)sender
{
    
    NSRange range = [display.text rangeOfString:@"."];
    if (range.location == NSNotFound) { //we don't already have a decimal point. 
       if(userIsInTheMiddleOfTypingANumber){
           display.text = [display.text stringByAppendingString:@"."];
       } else {
           display.text = @"0.";
           userIsInTheMiddleOfTypingANumber = YES;
       }
       //NSLog(@"%@", @"Not Found");
      
   } 
  
}

-(IBAction)backspacePressed:(UIButton *)sender
{
    double len = display.text.length;
    //NSLog(@"%g", len);
    if(userIsInTheMiddleOfTypingANumber){
        if(len > 1){
            display.text = [display.text substringToIndex: len-1];
        } else {
            display.text = @"0";
            userIsInTheMiddleOfTypingANumber=NO;
        }
    }
}



@end
